#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Compatibility functions."""

from __future__ import print_function
from __future__ import absolute_import

__author__ = "Lluís Vilanova"
__copyright__ = "Copyright 2016-2019, Lluís Vilanova"
__license__ = "GPL version 3 or later"


import inspect
import six
import sys


if sys.version_info < (3, 0):
    class InspectSignature(object):
        def __init__(self, func):
            self._func = func
            self._spec = inspect.getargspec(func)

        def __contains__(self, name):
            return name in self._spec.args

        def index(self, name):
            return self._spec.args.index(name)

    class InspectBind(object):
        def __init__(self, func, *args, **kwargs):
            self.args = []
            self.kwargs = inspect.getcallargs(func, *args, **kwargs)
            self.arguments = self.kwargs
else:
    class InspectSignature(object):
        def __init__(self, func):
            self._func = func
            self._sig = inspect.signature(func)

        def __contains__(self, name):
            return name in self._sig.parameters

        def index(self, name):
            return list(self._sig.parameters.keys()).index(name)

    class InspectBind(object):
        def __init__(self, func, *args, **kwargs):
            self._args = inspect.signature(func).bind(*args, **kwargs)
            self._args.apply_defaults()

        @property
        def args(self):
            return self._args.args

        @property
        def kwargs(self):
            return self._args.kwargs

        @property
        def arguments(self):
            return self._args.arguments


if sys.version_info < (3, 0):
    def StringIO(contents):
        return six.StringIO(contents)

else:
    def StringIO(contents):
        if isinstance(contents, str):
            contents = contents.encode('utf-8')
        return six.BytesIO(contents)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import print_function
from __future__ import absolute_import

__author__     = "Lluís Vilanova"
__copyright__  = "Copyright 2008-2019, Lluís Vilanova"
__license__    = "GPL version 3 or later"


__version_info__ = (2, 0, 3)
__version__ = ".".join([str(i) for i in __version_info__])



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import print_function
from __future__ import absolute_import

import os
import sys
from distutils.core import setup


def run(base):
    version_file = os.path.join(base, "sciexp2", "expdef", "__init__.py")
    with open(version_file) as f:
        code = compile(f.read(), version_file, 'exec')
        version = {}
        exec(code, {}, version) #, global_vars, local_vars)

    with open(os.path.join(base, ".requirements.txt"), "r") as f:
        reqs = [line[:-1] for line in f.readlines()]

    opts = dict(name="sciexp2-expdef",
                version=version["__version__"],
                description="Experiment definition framework for SciExp²",
                long_description="""\
SciExp²-ExpDef (aka *Scientific Experiment Exploration - Experiment Definition*)
provides a framework for defining experiments, creating all the files needed for
them and, finally, executing the experiments.

SciExp²-ExpDef puts a special emphasis in simplifying experiment design space
exploration, using a declarative interface for defining permutations of the
different parameters of your experiments, and templated files for the scripts
and configuration files for your experiments. SciExp²-ExpDef supports various
execution platforms like regular local scripts and cluster jobs. It takes care
of tracking their correct execution, and allows selecting which experiments to
run (e.g., those with specific parameter values, or those that were not
successfully run yet).
""",
                author="Lluís Vilanova",
                author_email="llvilanovag@gmail.com",
                url="https://sciexp2-expdef.readthedocs.io/",
                license="GNU General Public License (GPL) version 3 or later",
                classifiers=[
                    "Development Status :: 5 - Production/Stable",
                    "Environment :: Console",
                    "Intended Audience :: Science/Research",
                    "License :: OSI Approved :: GNU General Public License (GPL)",
                    "Programming Language :: Python",
                    "Topic :: Scientific/Engineering",
                ],
                packages=["sciexp2", "sciexp2.common", "sciexp2.expdef", "sciexp2.expdef.system"],
                package_data={"sciexp2": ["expdef/templates/*.dsc", "expdef/templates/*.tpl"]},
                scripts=["launcher"],
                requires=reqs,
                platforms="any",
    )

    setup(**opts)

if __name__ == "__main__":
    run(os.path.dirname(sys.argv[0]))
